summaryrefslogtreecommitdiff
path: root/src/login/fwd.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/login/fwd.hpp')
-rw-r--r--src/login/fwd.hpp22
1 files changed, 21 insertions, 1 deletions
diff --git a/src/login/fwd.hpp b/src/login/fwd.hpp
index 94fe3c0..6516404 100644
--- a/src/login/fwd.hpp
+++ b/src/login/fwd.hpp
@@ -20,8 +20,28 @@
#include "../sanity.hpp"
+#include "../ints/fwd.hpp" // rank 1
+#include "../strings/fwd.hpp" // rank 1
+#include "../compat/fwd.hpp"
+#include "../generic/fwd.hpp" // rank 3
+#include "../io/fwd.hpp" // rank 4
+#include "../net/fwd.hpp" // rank 5
+#include "../mmo/fwd.hpp" // rank 6
+#include "../proto2/fwd.hpp" // rank 8
+#include "../high/fwd.hpp" // rank 9
+#include "../wire/fwd.hpp" // rank 9
+// login/fwd.hpp is rank ∞ because it is an executable
+
namespace tmwa
{
-// meh, add more when I feel like it
+namespace login
+{
+ struct LoginConf;
+ struct LoginLanConf;
+ struct AuthFifo;
+ struct mmo_char_server;
+ struct AuthData;
+ // meh, add more when I feel like it
+} // namespace login
} // namespace tmwa